==> vtigercrm-5.0.4p0.tgz: vtigercrm/modules/Potentials/DetailViewAjax.php <==
<?php
/*********************************************************************************
 ** The contents of this file are subject to the vtiger CRM Public License Version 1.0
  * ("License"); You may not use this file except in compliance with the License
  * The Original Code is:  vtiger CRM Open Source
  * The Initial Developer of the Original Code is vtiger.
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
 *
  ********************************************************************************/

require_once('include/logging.php');
require_once('modules/Potentials/Potentials.php');
require_once('include/database/PearDatabase.php');
global $adb;

$local_log =& LoggerManager::getLogger('PotentialsAjax');

$ajaxaction = $_REQUEST["ajxaction"];
if($ajaxaction == "DETAILVIEW")
{
	$crmid = $_REQUEST["recordid"];
	$tablename = $_REQUEST["tableName"];
	$fieldname = $_REQUEST["fldName"];
	$fieldvalue = utf8RawUrlDecode($_REQUEST["fieldValue"]); 
	if($crmid != "")
	{
		$modObj = new Potentials();
		$modObj->retrieve_entity_info($crmid,"Potentials");
		$modObj->column_fields[$fieldname] = $fieldvalue;
		$_REQUEST[$fieldname] = $fieldvalue;
		if($fieldname == 'amount')//amount converted to dollar value while saving
		{
			$modObj->column_fields[$fieldname] = getConvertedPrice($fieldvalue);
		}	
		$modObj->id = $crmid;
		$modObj->mode = "edit";
		$modObj->save("Potentials");
	        sendNotificationToOwner('Potentials',&$modObj);
		if($modObj->id != "")
		{
			echo ":#:SUCCESS";
		}else
		{
			echo ":#:FAILURE";
		}   
	}else
	{
		echo ":#:FAILURE";
	}
}
?>

==> vtigercrm-5.1.0.tgz: vtigercrm/modules/Potentials/DetailViewAjax.php <==
<?php
/*+********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 *********************************************************************************/

require_once('include/logging.php');
require_once('include/database/PearDatabase.php');
global $adb;

$local_log =& LoggerManager::getLogger('PotentialsAjax');
global $currentModule;
$modObj = CRMEntity::getInstance($currentModule);

$ajaxaction = $_REQUEST["ajxaction"];
if($ajaxaction == "DETAILVIEW")
{
	$crmid = $_REQUEST["recordid"];
	$tablename = $_REQUEST["tableName"];
	$fieldname = $_REQUEST["fldName"];
	$fieldvalue = utf8RawUrlDecode($_REQUEST["fieldValue"]); 
	if($crmid != "")
	{
		$modObj->retrieve_entity_info($crmid,"Potentials");
		$modObj->column_fields[$fieldname] = $fieldvalue;
		$_REQUEST[$fieldname] = $fieldvalue;
		if($fieldname == 'amount')//amount converted to dollar value while saving
		{
			$modObj->column_fields[$fieldname] = getConvertedPrice($fieldvalue);
		}	
		$modObj->id = $crmid;
		$modObj->mode = "edit";
		$modObj->save("Potentials");
	        sendNotificationToOwner('Potentials',&$modObj);
		if($modObj->id != "")
		{
			echo ":#:SUCCESS";
		}else
		{
			echo ":#:FAILURE";
		}   
	}else
	{
		echo ":#:FAILURE";
	}
}
?>
